==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Vechna tmata");
define("_NOCOMMENTS","Bez komente");
define("_UCOMMENT","Koment");
define("_REVIEWS","Recenze");
define("_SEARCHUSERS","Hledat v databzi uivatel");
define("_SEARCHSECTIONS","Hledat ve speciln sekci");
define("_SEARCHREVIEWS","Hledat v recenzch");
define("_SEARCHIN","Prohledat");
define("_ARTICLES","lnky");
define("_ALLAUTHORS","Vechny autory");
define("_ALL","Ve");
define("_WEEK","tden");
define("_WEEKS","tdny");
define("_MONTH","msc");
define("_MONTHS","msce");
define("_SEARCHON","Hledat v:");
define("_SSTORIES","lnky");
define("_SSECTIONS","Sekce");
define("_SUSERS","Uivatel");
define("_NOMATCHES","Nebyl nalezen zznam na v poadavek");
define("_PREVMATCHES","pedchozch zznam");
define("_NEXTMATCHES","dal nalezen zaznamy");
define("_INSECTION","v sekci");
define("_NONAME","Nezadal(a) jmno");
define("_SCOMMENTS","Komente");
define("_SEARCHRESULTS","Vsledky hledn");
define("_CONTRIBUTEDBY","Pspvek poslal(a)");
define("_UCOMMENTS","Komente");
define("_MATCHTITLE","Porovnat nzev");
define("_MATCHTEXT","Porovnat text lnku");
define("_MATCHBOTH","Porovnat nzev i text lnku");
define("_SREPLY","Odpov");
define("_SREPLIES","Odpovdi");
define("_ATTACHART","Pdavky k lnku");
define("_PAGES","Strnky");
define("_REVIEWSCORE","Hodnocen pro tuto recenzi");
define("_PAGE","Strnka");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Vechna tmata");
define("_NOCOMMENTS","Bez komente");
define("_UCOMMENT","Koment");
define("_REVIEWS","Recenze");
define("_SEARCHUSERS","Hledat v databzi uivatel");
define("_SEARCHSECTIONS","Hledat ve speciln sekci");
define("_SEARCHREVIEWS","Hledat v recenzch");
define("_SEARCHIN","Prohledat");
define("_ARTICLES","lnky");
define("_ALLAUTHORS","Vechny autory");
define("_ALL","Ve");
define("_WEEK","tden");
define("_WEEKS","tdny");
define("_MONTH","msc");
define("_MONTHS","msce");
define("_SEARCHON","Hledat v:");
define("_SSTORIES","lnky");
define("_SSECTIONS","Sekce");
define("_SUSERS","Uivatel");
define("_NOMATCHES","Nebyl nalezen zznam na v poadavek");
define("_PREVMATCHES","pedchozch zznam");
define("_NEXTMATCHES","dal nalezen zaznamy");
define("_INSECTION","v sekci");
define("_NONAME","Nezadal(a) jmno");
define("_SCOMMENTS","Komente");
define("_SEARCHRESULTS","Vsledky hledn");
define("_CONTRIBUTEDBY","Pspvek poslal(a)");
define("_UCOMMENTS","Komente");
define("_MATCHTITLE","Porovnat nzev");
define("_MATCHTEXT","Porovnat text lnku");
define("_MATCHBOTH","Porovnat nzev i text lnku");
define("_SREPLY","Odpov");
define("_SREPLIES","Odpovdi");
define("_ATTACHART","Pdavky k lnku");
define("_PAGES","Strnky");
define("_REVIEWSCORE","Hodnocen pro tuto recenzi");
define("_PAGE","Strnka");

?>
